[java-identity-provider] branch master updated: Deprecate and adjust a method name.

Scott Cantor cantor.2 at osu.edu
Fri Jan 10 10:53:31 EST 2020


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch master
in repository java-identity-provider.

View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=5a81ea16d6c100568368431b3497f584b10c2ee5

The following commit(s) were added to refs/heads/master by this push:
       new  5a81ea1   Deprecate and adjust a method name.
5a81ea1 is described below

commit 5a81ea16d6c100568368431b3497f584b10c2ee5
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Fri Jan 10 10:53:27 2020 -0500

    Deprecate and adjust a method name.
---
 .../idp/attribute/IdPRequestedAttribute.java       | 22 ++++++++++++++++++----
 1 file changed, 18 insertions(+), 4 deletions(-)

diff --git a/idp-attribute-api/src/main/java/net/shibboleth/idp/attribute/IdPRequestedAttribute.java b/idp-attribute-api/src/main/java/net/shibboleth/idp/attribute/IdPRequestedAttribute.java
index f167686..f1111ec 100644
--- a/idp-attribute-api/src/main/java/net/shibboleth/idp/attribute/IdPRequestedAttribute.java
+++ b/idp-attribute-api/src/main/java/net/shibboleth/idp/attribute/IdPRequestedAttribute.java
@@ -37,10 +37,24 @@ public final class IdPRequestedAttribute extends IdPAttribute {
     }
 
     /**
-     * Is this attribute marked as required.
+     * Is this attribute marked as required?
      * 
-     * @return Returns the isRequired flag
+     * @return the isRequired flag
+     * 
+     * @since 4.0.0
+     */
+    public boolean isRequired() {
+        return isRequired;
+    }
+    
+    /**
+     * Is this attribute marked as required?
+     * 
+     * @return the isRequired flag
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval=true,since="4.0.0")
     public boolean getIsRequired() {
         return isRequired;
     }
@@ -51,7 +65,7 @@ public final class IdPRequestedAttribute extends IdPAttribute {
      * @param required The flag to set.
      */
     public void setRequired(final boolean required) {
-        this.isRequired = required;
+        isRequired = required;
     }
 
-}
+}
\ No newline at end of file

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list